==> mesa-19.2.0-x86_64-1.txz: install/doinst.sh <==
#!/bin/sh
config() {
  NEW="$1"
  OLD="`dirname $NEW`/`basename $NEW .new`"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}
# Don't mess with /etc/drirc. Mesa now installs the defaults as
# /usr/share/drirc.d/00-mesa-defaults.conf. We won't protect that
# as a .new file as it shouldn't be modified. Create /etc/drirc if
# you need local overrides.
#config etc/drirc.new
( cd usr/lib64/d3d ; rm -rf d3dadapter9.so )
( cd usr/lib64/d3d ; ln -sf d3dadapter9.so.1 d3dadapter9.so )
( cd usr/lib64/d3d ; rm -rf d3dadapter9.so.1 )
( cd usr/lib64/d3d ; ln -sf d3dadapter9.so.1.0.0 d3dadapter9.so.1 )
( cd usr/lib64 ; rm -rf libEGL_mesa.so )
( cd usr/lib64 ; ln -sf libEGL_mesa.so.0 libEGL_mesa.so )
( cd usr/lib64 ; rm -rf libEGL_mesa.so.0 )
( cd usr/lib64 ; ln -sf libEGL_mesa.so.0.0.0 libEGL_mesa.so.0 )
( cd usr/lib64 ; rm -rf libGLESv2.so )
( cd usr/lib64 ; ln -sf libGLESv2.so.2 libGLESv2.so )
( cd usr/lib64 ; rm -rf libGLESv2.so.2 )
( cd usr/lib64 ; ln -sf libGLESv2.so.2.0.0 libGLESv2.so.2 )
( cd usr/lib64 ; rm -rf libGLX_mesa.so )
( cd usr/lib64 ; ln -sf libGLX_mesa.so.0 libGLX_mesa.so )
( cd usr/lib64 ; rm -rf libGLX_mesa.so.0 )
( cd usr/lib64 ; ln -sf libGLX_mesa.so.0.0.0 libGLX_mesa.so.0 )
( cd usr/lib64 ; rm -rf libMesaOpenCL.so )
( cd usr/lib64 ; ln -sf libMesaOpenCL.so.1 libMesaOpenCL.so )
( cd usr/lib64 ; rm -rf libMesaOpenCL.so.1 )
( cd usr/lib64 ; ln -sf libMesaOpenCL.so.1.0.0 libMesaOpenCL.so.1 )
( cd usr/lib64 ; rm -rf libOSMesa.so )
( cd usr/lib64 ; ln -sf libOSMesa.so.8 libOSMesa.so )
( cd usr/lib64 ; rm -rf libOSMesa.so.8 )
( cd usr/lib64 ; ln -sf libOSMesa.so.8.0.0 libOSMesa.so.8 )
( cd usr/lib64 ; rm -rf libgbm.so )
( cd usr/lib64 ; ln -sf libgbm.so.1 libgbm.so )
( cd usr/lib64 ; rm -rf libgbm.so.1 )
( cd usr/lib64 ; ln -sf libgbm.so.1.0.0 libgbm.so.1 )
( cd usr/lib64 ; rm -rf libglapi.so )
( cd usr/lib64 ; ln -sf libglapi.so.0 libglapi.so )
( cd usr/lib64 ; rm -rf libglapi.so.0 )
( cd usr/lib64 ; ln -sf libglapi.so.0.0.0 libglapi.so.0 )
( cd usr/lib64 ; rm -rf libswrAVX.so )
( cd usr/lib64 ; ln -sf libswrAVX.so.0 libswrAVX.so )
( cd usr/lib64 ; rm -rf libswrAVX.so.0 )
( cd usr/lib64 ; ln -sf libswrAVX.so.0.0.0 libswrAVX.so.0 )
( cd usr/lib64 ; rm -rf libswrAVX2.so )
( cd usr/lib64 ; ln -sf libswrAVX2.so.0 libswrAVX2.so )
( cd usr/lib64 ; rm -rf libswrAVX2.so.0 )
( cd usr/lib64 ; ln -sf libswrAVX2.so.0.0.0 libswrAVX2.so.0 )
( cd usr/lib64 ; rm -rf libxatracker.so )
( cd usr/lib64 ; ln -sf libxatracker.so.2 libxatracker.so )
( cd usr/lib64 ; rm -rf libxatracker.so.2 )
( cd usr/lib64 ; ln -sf libxatracker.so.2.5.0 libxatracker.so.2 )
( cd usr/lib64/vdpau ; rm -rf libvdpau_nouveau.so )
( cd usr/lib64/vdpau ; ln -sf libvdpau_nouveau.so.1.0.0 libvdpau_nouveau.so )
( cd usr/lib64/vdpau ; rm -rf libvdpau_nouveau.so.1 )
( cd usr/lib64/vdpau ; ln -sf libvdpau_nouveau.so.1.0.0 libvdpau_nouveau.so.1 )
( cd usr/lib64/vdpau ; rm -rf libvdpau_nouveau.so.1.0 )
( cd usr/lib64/vdpau ; ln -sf libvdpau_nouveau.so.1.0.0 libvdpau_nouveau.so.1.0 )
( cd usr/lib64/vdpau ; rm -rf libvdpau_r300.so )
( cd usr/lib64/vdpau ; ln -sf libvdpau_r300.so.1.0.0 libvdpau_r300.so )
( cd usr/lib64/vdpau ; rm -rf libvdpau_r300.so.1 )
( cd usr/lib64/vdpau ; ln -sf libvdpau_r300.so.1.0.0 libvdpau_r300.so.1 )
( cd usr/lib64/vdpau ; rm -rf libvdpau_r300.so.1.0 )
( cd usr/lib64/vdpau ; ln -sf libvdpau_r300.so.1.0.0 libvdpau_r300.so.1.0 )
( cd usr/lib64/vdpau ; rm -rf libvdpau_r600.so )
( cd usr/lib64/vdpau ; ln -sf libvdpau_r600.so.1.0.0 libvdpau_r600.so )
( cd usr/lib64/vdpau ; rm -rf libvdpau_r600.so.1 )
( cd usr/lib64/vdpau ; ln -sf libvdpau_r600.so.1.0.0 libvdpau_r600.so.1 )
( cd usr/lib64/vdpau ; rm -rf libvdpau_r600.so.1.0 )
( cd usr/lib64/vdpau ; ln -sf libvdpau_r600.so.1.0.0 libvdpau_r600.so.1.0 )
( cd usr/lib64/vdpau ; rm -rf libvdpau_radeonsi.so )
( cd usr/lib64/vdpau ; ln -sf libvdpau_radeonsi.so.1.0.0 libvdpau_radeonsi.so )
( cd usr/lib64/vdpau ; rm -rf libvdpau_radeonsi.so.1 )
( cd usr/lib64/vdpau ; ln -sf libvdpau_radeonsi.so.1.0.0 libvdpau_radeonsi.so.1 )
( cd usr/lib64/vdpau ; rm -rf libvdpau_radeonsi.so.1.0 )
( cd usr/lib64/vdpau ; ln -sf libvdpau_radeonsi.so.1.0.0 libvdpau_radeonsi.so.1.0 )

==> mesa-20.3.0-x86_64-1.txz: install/doinst.sh <==
#!/bin/sh
config() {
  NEW="$1"
  OLD="`dirname $NEW`/`basename $NEW .new`"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}
# Don't mess with /etc/drirc. Mesa now installs the defaults as
# /usr/share/drirc.d/00-mesa-defaults.conf. We won't protect that
# as a .new file as it shouldn't be modified. Create /etc/drirc if
# you need local overrides.
#config etc/drirc.new
( cd usr/lib64/d3d ; rm -rf d3dadapter9.so )
( cd usr/lib64/d3d ; ln -sf d3dadapter9.so.1 d3dadapter9.so )
( cd usr/lib64/d3d ; rm -rf d3dadapter9.so.1 )
( cd usr/lib64/d3d ; ln -sf d3dadapter9.so.1.0.0 d3dadapter9.so.1 )
( cd usr/lib64 ; rm -rf libEGL_mesa.so )
( cd usr/lib64 ; ln -sf libEGL_mesa.so.0 libEGL_mesa.so )
( cd usr/lib64 ; rm -rf libEGL_mesa.so.0 )
( cd usr/lib64 ; ln -sf libEGL_mesa.so.0.0.0 libEGL_mesa.so.0 )
( cd usr/lib64 ; rm -rf libGLX_mesa.so )
( cd usr/lib64 ; ln -sf libGLX_mesa.so.0 libGLX_mesa.so )
( cd usr/lib64 ; rm -rf libGLX_mesa.so.0 )
( cd usr/lib64 ; ln -sf libGLX_mesa.so.0.0.0 libGLX_mesa.so.0 )
( cd usr/lib64 ; rm -rf libMesaOpenCL.so )
( cd usr/lib64 ; ln -sf libMesaOpenCL.so.1 libMesaOpenCL.so )
( cd usr/lib64 ; rm -rf libMesaOpenCL.so.1 )
( cd usr/lib64 ; ln -sf libMesaOpenCL.so.1.0.0 libMesaOpenCL.so.1 )
( cd usr/lib64 ; rm -rf libOSMesa.so )
( cd usr/lib64 ; ln -sf libOSMesa.so.8 libOSMesa.so )
( cd usr/lib64 ; rm -rf libOSMesa.so.8 )
( cd usr/lib64 ; ln -sf libOSMesa.so.8.0.0 libOSMesa.so.8 )
( cd usr/lib64 ; rm -rf libXvMCnouveau.so )
( cd usr/lib64 ; ln -sf libXvMCnouveau.so.1.0.0 libXvMCnouveau.so )
( cd usr/lib64 ; rm -rf libXvMCnouveau.so.1 )
( cd usr/lib64 ; ln -sf libXvMCnouveau.so.1.0.0 libXvMCnouveau.so.1 )
( cd usr/lib64 ; rm -rf libXvMCnouveau.so.1.0 )
( cd usr/lib64 ; ln -sf libXvMCnouveau.so.1.0.0 libXvMCnouveau.so.1.0 )
( cd usr/lib64 ; rm -rf libXvMCr600.so )
( cd usr/lib64 ; ln -sf libXvMCr600.so.1.0.0 libXvMCr600.so )
( cd usr/lib64 ; rm -rf libXvMCr600.so.1 )
( cd usr/lib64 ; ln -sf libXvMCr600.so.1.0.0 libXvMCr600.so.1 )
( cd usr/lib64 ; rm -rf libXvMCr600.so.1.0 )
( cd usr/lib64 ; ln -sf libXvMCr600.so.1.0.0 libXvMCr600.so.1.0 )
( cd usr/lib64 ; rm -rf libgbm.so )
( cd usr/lib64 ; ln -sf libgbm.so.1 libgbm.so )
( cd usr/lib64 ; rm -rf libgbm.so.1 )
( cd usr/lib64 ; ln -sf libgbm.so.1.0.0 libgbm.so.1 )
( cd usr/lib64 ; rm -rf libglapi.so )
( cd usr/lib64 ; ln -sf libglapi.so.0 libglapi.so )
( cd usr/lib64 ; rm -rf libglapi.so.0 )
( cd usr/lib64 ; ln -sf libglapi.so.0.0.0 libglapi.so.0 )
( cd usr/lib64 ; rm -rf libswrAVX.so )
( cd usr/lib64 ; ln -sf libswrAVX.so.0 libswrAVX.so )
( cd usr/lib64 ; rm -rf libswrAVX.so.0 )
( cd usr/lib64 ; ln -sf libswrAVX.so.0.0.0 libswrAVX.so.0 )
( cd usr/lib64 ; rm -rf libswrAVX2.so )
( cd usr/lib64 ; ln -sf libswrAVX2.so.0 libswrAVX2.so )
( cd usr/lib64 ; rm -rf libswrAVX2.so.0 )
( cd usr/lib64 ; ln -sf libswrAVX2.so.0.0.0 libswrAVX2.so.0 )
( cd usr/lib64 ; rm -rf libxatracker.so )
( cd usr/lib64 ; ln -sf libxatracker.so.2 libxatracker.so )
( cd usr/lib64 ; rm -rf libxatracker.so.2 )
( cd usr/lib64 ; ln -sf libxatracker.so.2.5.0 libxatracker.so.2 )
( cd usr/lib64/vdpau ; rm -rf libvdpau_nouveau.so )
( cd usr/lib64/vdpau ; ln -sf libvdpau_nouveau.so.1.0.0 libvdpau_nouveau.so )
( cd usr/lib64/vdpau ; rm -rf libvdpau_nouveau.so.1 )
( cd usr/lib64/vdpau ; ln -sf libvdpau_nouveau.so.1.0.0 libvdpau_nouveau.so.1 )
( cd usr/lib64/vdpau ; rm -rf libvdpau_nouveau.so.1.0 )
( cd usr/lib64/vdpau ; ln -sf libvdpau_nouveau.so.1.0.0 libvdpau_nouveau.so.1.0 )
( cd usr/lib64/vdpau ; rm -rf libvdpau_r300.so )
( cd usr/lib64/vdpau ; ln -sf libvdpau_r300.so.1.0.0 libvdpau_r300.so )
( cd usr/lib64/vdpau ; rm -rf libvdpau_r300.so.1 )
( cd usr/lib64/vdpau ; ln -sf libvdpau_r300.so.1.0.0 libvdpau_r300.so.1 )
( cd usr/lib64/vdpau ; rm -rf libvdpau_r300.so.1.0 )
( cd usr/lib64/vdpau ; ln -sf libvdpau_r300.so.1.0.0 libvdpau_r300.so.1.0 )
( cd usr/lib64/vdpau ; rm -rf libvdpau_r600.so )
( cd usr/lib64/vdpau ; ln -sf libvdpau_r600.so.1.0.0 libvdpau_r600.so )
( cd usr/lib64/vdpau ; rm -rf libvdpau_r600.so.1 )
( cd usr/lib64/vdpau ; ln -sf libvdpau_r600.so.1.0.0 libvdpau_r600.so.1 )
( cd usr/lib64/vdpau ; rm -rf libvdpau_r600.so.1.0 )
( cd usr/lib64/vdpau ; ln -sf libvdpau_r600.so.1.0.0 libvdpau_r600.so.1.0 )
( cd usr/lib64/vdpau ; rm -rf libvdpau_radeonsi.so )
( cd usr/lib64/vdpau ; ln -sf libvdpau_radeonsi.so.1.0.0 libvdpau_radeonsi.so )
( cd usr/lib64/vdpau ; rm -rf libvdpau_radeonsi.so.1 )
( cd usr/lib64/vdpau ; ln -sf libvdpau_radeonsi.so.1.0.0 libvdpau_radeonsi.so.1 )
( cd usr/lib64/vdpau ; rm -rf libvdpau_radeonsi.so.1.0 )
( cd usr/lib64/vdpau ; ln -sf libvdpau_radeonsi.so.1.0.0 libvdpau_radeonsi.so.1.0 )
